var indexSectionsWithContent =
{
  0: "0123456789:_abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghijklmnopqrstuvwxz",
  2: "abcdefghilmnoprstuvw",
  3: "123456789abcdefghijklmnopqrstuvw",
  4: "abcdefghijklmnopqrstuvwxz~",
  5: "_abcdefghijklmnopqrstuvwxyz",
  6: "abcdefghijklmnopqrstuvw",
  7: "abcdefghilmnopqrstuvw",
  8: "abcdefghijklmnopqrstuvwxz",
  9: ":abcdfgilmnoprstuv",
  10: "abdefhimpst",
  11: "abcdefghilmnopqrstuvw",
  12: "0123456789:abcdefghijklmnopqrstuvwxy",
  13: "i"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "groups",
  12: "pages",
  13: "concepts"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Modules",
  12: "Pages",
  13: "Concepts"
};

